package mod.common.neural;

public class NetworkRunner {
	
	private Network net;
	public int noOfInput;
	public int noOfOutput;
	
	public NetworkRunner(Network net){
		this.net=net;
		noOfInput=net.NoOfInput;
		noOfOutput=net.NoOfOutput;
	}
	
	public Network getNetwork(){
		return net;
	}
	
	private float Act_Logistic(float sum, float bias) {
		return ((sum + bias) < 10000f) ? (1f / (1f + exp(-sum - bias))): 0f;
	}

	private float exp(float value) {
		if (value == 0.)
			return 1f;
		float f = 1, k;
		boolean isless = (value < 0.);
		if (isless)
			value = -value;
		k = value;
		for (int i = 2; i < 6; i++) {
			f = f + k;
			k = k * value / i;
		}
		if (isless)
			return 1 / f;
		return f;
	}

	/*****************************************************************************
	 * FUNCTION : NtForwardProp
	 * 
	 * PURPOSE : Calculus of the output values from inputs RETURNS : a value
	 * that represent WTA value NOTES :
	 * 
	 * UPDATE :
	 ******************************************************************************/
	public int NtForwardProp(float[] in, float[] out) throws Exception {
		int member, source;
		float sum;
		UT unit;

		for (member = 0; member < net.NoOfInput; member++)
			net.Input[member].act = in[member];
		
		for (member = 0; member < net.NoOfHidden; member++) {
			unit = net.Hidden[member];
			sum = 0f;
			for (source = 0; source < unit.NoOfSources; source++) 
				sum += unit.sources[source].act * unit.weights[source];
			
			unit.act = Act_Logistic(sum, unit.Bias);
		}

		for (member = 0; member < net.NoOfOutput; member++) {
			unit = net.Output[member];
			sum = 0f;
			for (source = 0; source < unit.NoOfSources; source++)
				sum += unit.sources[source].act * unit.weights[source];
			
			unit.act = Act_Logistic(sum, unit.Bias);
		}

		for (member = 0; member < net.NoOfOutput; member++)
			out[member] = net.Units[net.OutputNum[member]].act;

		return WTA(out);
	}

	// Winner Take All: ritorna l'etichetta (1...#C) della classe vincitrice
	private int WTA(float[] out) {
		int winner = 1;
		float max = out[0];
		for (int i = 0; i < net.NoOfOutput; i++) {
			if (out[i] > max) {
				max = out[i];
				winner = i + 1;
			}
		}
		// soglia
		if (max < 0.1)
			return 0; // NC
		return winner;
	}

}
